![PyPI - Downloads](https://img.shields.io/pypi/dm/glcm-cupy?style=for-the-badge)
![PyPI](https://img.shields.io/pypi/v/glcm-cupy?style=for-the-badge)
![PyPI - License](https://img.shields.io/pypi/l/glcm-cupy?style=for-the-badge)

# Binned GLCM Features on CuPy

Directly utilize CUDA to speed up the processing of GLCM in Python.

## 📖 Documentation

- [Read The Wiki](https://eve-ning.github.io/glcm-cupy/)
    - [Installation Guide](https://eve-ning.github.io/glcm-cupy/setup/installation.html)
    - [Get Started with GLCM](https://eve-ning.github.io/glcm-cupy/setup/glcm_usage.html)
    - [Get Started with GLCM Cross](https://eve-ning.github.io/glcm-cupy/setup/glcm_cross_usage.html)

## Contributors

- [Julio Faracco](https://github.com/jcfaracco)
    - Special Thanks for implementing [**CuPy input support!**](https://github.com/Eve-ning/glcm-cupy/pull/18)

## Acknowledgements

I extend my gratitude to the following people

| Acknowledgement | Contribution                                            |
|-----------------|---------------------------------------------------------|
| Benjamin Goh    | Motivated the project after his implementation in Numba |
| Dr. Ji-Jon Sit  | Hosted & Guided the URECA project that started this     |
| Wang Jifei      | For providing the idea for GLCM Binning                 |
